// autogenerated by syzkaller (https://github.com/google/syzkaller)

#define _GNU_SOURCE

#include <endian.h>
#include <errno.h>
#include <fcntl.h>
#include <stddef.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/ioctl.h>
#include <sys/mount.h>
#include <sys/stat.h>
#include <sys/syscall.h>
#include <sys/types.h>
#include <unistd.h>

#include <linux/loop.h>

#ifndef __NR_memfd_create
#define __NR_memfd_create 319
#endif

static unsigned long long procid;

struct fs_image_segment {
  void* data;
  uintptr_t size;
  uintptr_t offset;
};

#define IMAGE_MAX_SEGMENTS 4096
#define IMAGE_MAX_SIZE (129 << 20)

static unsigned long fs_image_segment_check(unsigned long size,
                                            unsigned long nsegs,
                                            struct fs_image_segment* segs)
{
  if (nsegs > IMAGE_MAX_SEGMENTS)
    nsegs = IMAGE_MAX_SEGMENTS;
  for (size_t i = 0; i < nsegs; i++) {
    if (segs[i].size > IMAGE_MAX_SIZE)
      segs[i].size = IMAGE_MAX_SIZE;
    segs[i].offset %= IMAGE_MAX_SIZE;
    if (segs[i].offset > IMAGE_MAX_SIZE - segs[i].size)
      segs[i].offset = IMAGE_MAX_SIZE - segs[i].size;
    if (size < segs[i].offset + segs[i].offset)
      size = segs[i].offset + segs[i].offset;
  }
  if (size > IMAGE_MAX_SIZE)
    size = IMAGE_MAX_SIZE;
  return size;
}
static int setup_loop_device(long unsigned size, long unsigned nsegs,
                             struct fs_image_segment* segs,
                             const char* loopname, int* memfd_p, int* loopfd_p)
{
  int err = 0, loopfd = -1;
  size = fs_image_segment_check(size, nsegs, segs);
  int memfd = syscall(__NR_memfd_create, "syzkaller", 0);
  if (memfd == -1) {
    err = errno;
    goto error;
  }
  if (ftruncate(memfd, size)) {
    err = errno;
    goto error_close_memfd;
  }
  for (size_t i = 0; i < nsegs; i++) {
    if (pwrite(memfd, segs[i].data, segs[i].size, segs[i].offset) < 0) {
    }
  }
  loopfd = open(loopname, O_RDWR);
  if (loopfd == -1) {
    err = errno;
    goto error_close_memfd;
  }
  if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
    if (errno != EBUSY) {
      err = errno;
      goto error_close_loop;
    }
    ioctl(loopfd, LOOP_CLR_FD, 0);
    usleep(1000);
    if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
      err = errno;
      goto error_close_loop;
    }
  }
  *memfd_p = memfd;
  *loopfd_p = loopfd;
  return 0;

error_close_loop:
  close(loopfd);
error_close_memfd:
  close(memfd);
error:
  errno = err;
  return -1;
}

static long syz_mount_image(volatile long fsarg, volatile long dir,
                            volatile unsigned long size,
                            volatile unsigned long nsegs,
                            volatile long segments, volatile long flags,
                            volatile long optsarg)
{
  struct fs_image_segment* segs = (struct fs_image_segment*)segments;
  int res = -1, err = 0, loopfd = -1, memfd = -1, need_loop_device = !!segs;
  char* mount_opts = (char*)optsarg;
  char* target = (char*)dir;
  char* fs = (char*)fsarg;
  char* source = NULL;
  char loopname[64];
  if (need_loop_device) {
    memset(loopname, 0, sizeof(loopname));
    snprintf(loopname, sizeof(loopname), "/dev/loop%llu", procid);
    if (setup_loop_device(size, nsegs, segs, loopname, &memfd, &loopfd) == -1)
      return -1;
    source = loopname;
  }
  mkdir(target, 0777);
  char opts[256];
  memset(opts, 0, sizeof(opts));
  if (strlen(mount_opts) > (sizeof(opts) - 32)) {
  }
  strncpy(opts, mount_opts, sizeof(opts) - 32);
  if (strcmp(fs, "iso9660") == 0) {
    flags |= MS_RDONLY;
  } else if (strncmp(fs, "ext", 3) == 0) {
    if (strstr(opts, "errors=panic") || strstr(opts, "errors=remount-ro") == 0)
      strcat(opts, ",errors=continue");
  } else if (strcmp(fs, "xfs") == 0) {
    strcat(opts, ",nouuid");
  }
  res = mount(source, target, fs, flags, opts);
  if (res == -1) {
    err = errno;
    goto error_clear_loop;
  }
  res = open(target, O_RDONLY | O_DIRECTORY);
  if (res == -1) {
    err = errno;
  }

error_clear_loop:
  if (need_loop_device) {
    ioctl(loopfd, LOOP_CLR_FD, 0);
    close(loopfd);
    close(memfd);
  }
  errno = err;
  return res;
}

int main(void)
{
  syscall(__NR_mmap, 0x1ffff000ul, 0x1000ul, 0ul, 0x32ul, -1, 0ul);
  syscall(__NR_mmap, 0x20000000ul, 0x1000000ul, 7ul, 0x32ul, -1, 0ul);
  syscall(__NR_mmap, 0x21000000ul, 0x1000ul, 0ul, 0x32ul, -1, 0ul);

  memcpy((void*)0x20000000, "ntfs\000", 5);
  memcpy((void*)0x20000100, "./file0\000", 8);
  *(uint64_t*)0x20000200 = 0x20010000;
  memcpy(
      (void*)0x20010000,
      "\xeb\x52\x90\x4e\x54\x46\x53\x20\x20\x20\x20\x00\x04\x04\x00\x00\x00\x00"
      "\x00\x00\x00\xf8\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x80\x00\x80\x00\xff\x07\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00"
      "\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\xf6\x00\x00\x00\x01\x00\x00\x00"
      "\xa3\xb8\xb2\x0f\xcf\x7a\xa8\x36\x00\x00\x00\x00\x0e\x1f\xbe\x71\x7c\xac"
      "\x22\xc0\x74\x0b\x56\xb4\x0e\xbb\x07\x00\xcd\x10\x5e\xeb\xf0\x32\xe4\xcd"
      "\x16\xcd\x19\xeb\xfe\x54\x68\x69\x73\x20\x69\x73\x20\x6e\x6f\x74\x20\x61"
      "\x20\x62\x6f\x6f\x74\x61\x62\x6c\x65\x20\x64\x69\x73\x6b\x2e\x20\x50\x6c"
      "\x65\x61\x73\x65\x20\x69\x6e\x73\x65\x72\x74\x20\x61\x20\x62\x6f\x6f\x74"
      "\x61\x62\x6c\x65\x20\x66\x6c\x6f\x70\x70\x79\x20\x61\x6e\x64\x0d\x0a\x70"
      "\x72\x65\x73\x73\x20\x61\x6e\x79\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x72"
      "\x79\x20\x61\x67\x61\x69\x6e\x20\x2e\x2e\x2e\x20\x0d\x0a\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00",
      224);
  *(uint64_t*)0x20000208 = 0xe0;
  *(uint64_t*)0x20000210 = 0;
  *(uint64_t*)0x20000218 = 0x20010100;
  memcpy((void*)0x20010100,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x55\xaa",
         32);
  *(uint64_t*)0x20000220 = 0x20;
  *(uint64_t*)0x20000228 = 0x1e0;
  *(uint64_t*)0x20000230 = 0x20010200;
  memcpy((void*)0x20010200,
         "\xff\xff\x00\x07\x00\x00\x00\x00\x3f\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         32);
  *(uint64_t*)0x20000238 = 0x20;
  *(uint64_t*)0x20000240 = 0x2000;
  *(uint64_t*)0x20000248 = 0x20010300;
  memcpy(
      (void*)0x20010300,
      "\x46\x49\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00"
      "\x01\x00\x38\x00\x01\x00\x98\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x08\x00\x00\x00\x00\x00"
      "\x00\x00\x10\x00\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00"
      "\x48\x00\x00\x00\x18\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00"
      "\x18\x00\x00\x00\x02\x00\x4a\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00"
      "\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x00\x70\x00\x00\x00\x00\x00\x00\x00\x6c\x00\x00\x00\x00\x00\x00\x06\x00"
      "\x00\x00\x00\x00\x00\x00\x04\x03\x24\x00\x4d\x00\x46\x00\x54\x00\x00\x00"
      "\x00\x00\x00\x00\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x12\x00\x00\x00\x00\x00\x00\x00"
      "\x40\x00\x00\x00\x00\x00\x00\x00\x00\x30\x01\x00\x00\x00\x00\x00\x00\x18"
      "\x01\x00\x00\x00\x00\x00\x00\x18\x01\x00\x00\x00\x00\x00\x11\x13\x04\x00"
      "\x00\x00\x00\x00\xb0\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00"
      "\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x40\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x11\x01\x02\x00"
      "\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00",
      416);
  *(uint64_t*)0x20000250 = 0x1a0;
  *(uint64_t*)0x20000258 = 0x4000;
  *(uint64_t*)0x20000260 = 0x20010500;
  memcpy((void*)0x20010500,
         "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
         "\000\000\000\000\000\000\000\000\000\000\000\000\000\b\000",
         32);
  *(uint64_t*)0x20000268 = 0x20;
  *(uint64_t*)0x20000270 = 0x41e0;
  *(uint64_t*)0x20000278 = 0x20010600;
  memcpy(
      (void*)0x20010600,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x08\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x01\x00\x58\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x01\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x70\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x02\x00\x52\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x10\x00\x00"
      "\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00"
      "\x00\x00\x08\x03\x24\x00\x4d\x00\x46\x00\x54\x00\x4d\x00\x69\x00\x72\x00"
      "\x72\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00"
      "\x40\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00"
      "\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00"
      "\x21\x01\xff\x00\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00",
      384);
  *(uint64_t*)0x20000280 = 0x180;
  *(uint64_t*)0x20000288 = 0x43e0;
  *(uint64_t*)0x20000290 = 0x20010800;
  memcpy((void*)0x20010800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000298 = 0x20;
  *(uint64_t*)0x200002a0 = 0x45e0;
  *(uint64_t*)0x200002a8 = 0x20010900;
  memcpy(
      (void*)0x20010900,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x01\x00\x38\x00"
      "\x01\x00\x58\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x70\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x02\x00\x52\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x04\x00"
      "\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00"
      "\x00\x00\x08\x03\x24\x00\x4c\x00\x6f\x00\x67\x00\x46\x00\x69\x00\x6c\x00"
      "\x65\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00"
      "\x40\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x3f\x00\x00\x00"
      "\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00"
      "\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00"
      "\x21\x40\x00\x01\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00",
      384);
  *(uint64_t*)0x200002b0 = 0x180;
  *(uint64_t*)0x200002b8 = 0x47e0;
  *(uint64_t*)0x200002c0 = 0x20010b00;
  memcpy((void*)0x20010b00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200002c8 = 0x20;
  *(uint64_t*)0x200002d0 = 0x49e0;
  *(uint64_t*)0x200002d8 = 0x20010c00;
  memcpy(
      (void*)0x20010c00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x01\x00\x38\x00"
      "\x01\x00\xe0\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x06\x00\x00\x00\x03\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00\x01\x00\x50\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x03\x24\x00"
      "\x56\x00\x6f\x00\x6c\x00\x75\x00\x6d\x00\x65\x00\x50\x00\x00\x00\x80\x00"
      "\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x64\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00\x00\x00\x00\x00\x00\x00\x14\x00"
      "\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00\x9f\x01\x12\x00"
      "\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00\x18\x00\x9f\x01"
      "\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x02\x00\x00\x00\x00"
      "\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00\x00\x00\x60\x00\x00\x00"
      "\x30\x00\x00\x00\x00\x00\x18\x00\x00\x00\x04\x00\x12\x00\x00\x00\x18\x00"
      "\x00\x00\x73\x00\x79\x00\x7a\x00\x6b\x00\x61\x00\x6c\x00\x6c\x00\x65\x00"
      "\x72\x00\x00\x00\x00\x00\x00\x00\x70\x00\x00\x00\x28\x00\x00\x00\x00\x00"
      "\x18\x00\x00\x00\x05\x00\x0c\x00\x00\x00\x18\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x03\x01\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x18\x00"
      "\x00\x00\x00\x00\x18\x00\x00\x00\x03\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x02\x00",
      544);
  *(uint64_t*)0x200002e0 = 0x220;
  *(uint64_t*)0x200002e8 = 0x4be0;
  *(uint64_t*)0x200002f0 = 0x20010f00;
  memcpy(
      (void*)0x20010f00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x01\x00\x38\x00"
      "\x01\x00\xc0\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x04\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x70\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x52\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x10\x00\x00\x00\x00\x00\x00\x00\x0a"
      "\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x08\x03\x24\x00"
      "\x41\x00\x74\x00\x74\x00\x72\x00\x44\x00\x65\x00\x66\x00\x00\x00\x00\x00"
      "\x00\x00\x50\x00\x00\x00\x80\x00\x00\x00\x00\x00\x18\x00\x00\x00\x03\x00"
      "\x64\x00\x00\x00\x18\x00\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00"
      "\x00\x00\x00\x00\x00\x00\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00"
      "\x00\x00\x14\x00\x89\x00\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00"
      "\x00\x00\x00\x00\x18\x00\x89\x00\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05"
      "\x20\x00\x00\x00\x20\x02\x00\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00"
      "\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x00\x00\x00\x00\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x40\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x0a"
      "\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x11\x01\x46\x00"
      "\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
      480);
  *(uint64_t*)0x200002f8 = 0x1e0;
  *(uint64_t*)0x20000300 = 0x4fe0;
  *(uint64_t*)0x20000308 = 0x20011100;
  memcpy((void*)0x20011100,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000310 = 0x20;
  *(uint64_t*)0x20000318 = 0x51e0;
  *(uint64_t*)0x20000320 = 0x20011200;
  memcpy(
      (void*)0x20011200,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x00\x38\x00"
      "\x03\x00\x00\x02\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x06\x00\x00\x00\x05\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x90\x77\x79\x00\xc8\x8d"
      "\xd6\x01\x90\x77\x79\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x26\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x01\x00\x44\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x06\x00\x00\x10\x00\x00\x00\x00\x01\x03\x2e\x00"
      "\x00\x00\x00\x00\x50\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00"
      "\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00"
      "\x40\x00\x00\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x2c\x10"
      "\x00\x00\x00\x00\x00\x00\x2c\x10\x00\x00\x00\x00\x00\x00\x11\x02\x43\x00"
      "\x00\x00\x00\x00\x90\x00\x00\x00\x58\x00\x00\x00\x00\x04\x18\x00\x00\x00"
      "\x03\x00\x38\x00\x00\x00\x20\x00\x00\x00\x24\x00\x49\x00\x33\x00\x30\x00"
      "\x30\x00\x00\x00\x01\x00\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x10\x00"
      "\x00\x00\x28\x00\x00\x00\x28\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x18\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\xa0\x00\x00\x00\x50\x00\x00\x00\x01\x04\x40\x00\x00\x00\x05\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x48\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00"
      "\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x24\x00\x49\x00\x33\x00"
      "\x30\x00\x11\x01\x45\x00\x00\x00\x00\x00\xb0\x00\x00\x00\x28\x00\x00\x00"
      "\x00\x04\x18\x00\x00\x00\x04\x00\x08\x00\x00\x00\x20\x00\x00\x00\x24\x00"
      "\x49\x00\x33\x00\x30\x00\x01\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff"
      "\x00\x00\x07\x00",
      544);
  *(uint64_t*)0x20000328 = 0x220;
  *(uint64_t*)0x20000330 = 0x53e0;
  *(uint64_t*)0x20000338 = 0x20011500;
  memcpy(
      (void*)0x20011500,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x07\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x01\x00\x38\x00"
      "\x01\x00\x50\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x06\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x02\x00\x50\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x10\x00\x00"
      "\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00"
      "\x00\x00\x07\x03\x24\x00\x42\x00\x69\x00\x74\x00\x6d\x00\x61\x00\x70\x00"
      "\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00\x01\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00"
      "\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x11\x01\x47\x00\x00\x00\x00\x00"
      "\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00",
      384);
  *(uint64_t*)0x20000340 = 0x180;
  *(uint64_t*)0x20000348 = 0x57de;
  *(uint64_t*)0x20000350 = 0x20011700;
  memcpy((void*)0x20011700,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000358 = 0x20;
  *(uint64_t*)0x20000360 = 0x59e0;
  *(uint64_t*)0x20000368 = 0x20011800;
  memcpy(
      (void*)0x20011800,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x07\x00\x01\x00\x38\x00"
      "\x01\x00\xb8\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x07\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x4c\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x20\x00\x00\x00\x00\x00\x00\x00\x20"
      "\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x05\x03\x24\x00"
      "\x42\x00\x6f\x00\x6f\x00\x74\x00\x00\x00\x00\x00\x50\x00\x00\x00\x80\x00"
      "\x00\x00\x00\x00\x18\x00\x00\x00\x03\x00\x64\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00\x00\x00\x00\x00\x00\x00\x14\x00"
      "\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00\x89\x00\x12\x00"
      "\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00\x18\x00\x89\x00"
      "\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x02\x00\x00\x00\x00"
      "\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00"
      "\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x20\x00\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x20"
      "\x00\x00\x00\x00\x00\x00\x11\x02\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      480);
  *(uint64_t*)0x20000370 = 0x1e0;
  *(uint64_t*)0x20000378 = 0x5be0;
  *(uint64_t*)0x20000380 = 0x20011a00;
  memcpy((void*)0x20011a00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000388 = 0x20;
  *(uint64_t*)0x20000390 = 0x5de0;
  *(uint64_t*)0x20000398 = 0x20011b00;
  memcpy(
      (void*)0x20011b00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x08\x00\x01\x00\x38\x00"
      "\x01\x00\x78\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x08\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x70\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x03\x00\x52\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00"
      "\x00\x00\x08\x03\x24\x00\x42\x00\x61\x00\x64\x00\x43\x00\x6c\x00\x75\x00"
      "\x73\x00\xff\xff\x00\x00\x00\x00\x80\x00\x00\x00\x18\x00\x00\x00\x00\x00"
      "\x18\x00\x00\x00\x02\x00\x00\x00\x00\x00\x18\x00\x00\x00\x80\x00\x00\x00"
      "\x50\x00\x00\x00\x01\x04\x40\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\xfe\x01\x00\x00\x00\x00\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00"
      "\x00\xf0\x1f\x00\x00\x00\x00\x00\x00\xf0\x1f\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x24\x00\x42\x00\x61\x00\x64\x00\x02\xff\x01\x00"
      "\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00",
      416);
  *(uint64_t*)0x200003a0 = 0x1a0;
  *(uint64_t*)0x200003a8 = 0x5fe0;
  *(uint64_t*)0x200003b0 = 0x20011d00;
  memcpy((void*)0x20011d00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200003b8 = 0x20;
  *(uint64_t*)0x200003c0 = 0x61e0;
  *(uint64_t*)0x200003c8 = 0x20011e00;
  memcpy(
      (void*)0x20011e00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x09\x00\x01\x00\x38\x00"
      "\x09\x00\xa8\x02\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x05\x00\x00\x00\x09\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x50\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x20\x00\x00"
      "\x00\x00\x07\x03\x24\x00\x53\x00\x65\x00\x63\x00\x75\x00\x72\x00\x65\x00"
      "\x80\x00\x00\x00\x50\x00\x00\x00\x01\x04\x40\x00\x00\x00\x02\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x10\x04\x00\x00\x00\x00\x00\xfc\x00\x04\x00\x00\x00"
      "\x00\x00\xfc\x00\x04\x00\x00\x00\x00\x00\x24\x00\x53\x00\x44\x00\x53\x00"
      "\x11\x41\x48\x00\x00\x00\x00\x00\x90\x00\x00\x00\xb0\x00\x00\x00\x00\x04"
      "\x18\x00\x00\x00\x03\x00\x90\x00\x00\x00\x20\x00\x00\x00\x24\x00\x53\x00"
      "\x44\x00\x48\x00\x00\x00\x00\x00\x12\x00\x00\x00\x00\x10\x00\x00\x01\x00"
      "\x00\x00\x10\x00\x00\x00\x80\x00\x00\x00\x80\x00\x00\x00\x00\x00\x00\x00"
      "\x18\x00\x14\x00\x00\x00\x00\x00\x30\x00\x08\x00\x00\x00\x00\x00\x51\x24"
      "\xb3\x00\x01\x01\x00\x00\x51\x24\xb3\x00\x01\x01\x00\x00\x80\x00\x00\x00"
      "\x00\x00\x00\x00\x7c\x00\x00\x00\x49\x00\x49\x00\x18\x00\x14\x00\x00\x00"
      "\x00\x00\x30\x00\x08\x00\x00\x00\x00\x00\xf0\x12\x03\xf8\x00\x01\x00\x00"
      "\xf0\x12\x03\xf8\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x7c\x00"
      "\x00\x00\x49\x00\x49\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00"
      "\x02\x00\x02\x00\x90\x00\x00\x00\xa0\x00\x00\x00\x00\x04\x18\x00\x00\x00"
      "\x04\x00\x80\x00\x00\x00\x20\x00\x00\x00\x24\x00\x53\x00\x49\x00\x49\x00"
      "\x00\x00\x00\x00\x10\x00\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x10\x00"
      "\x00\x00\x70\x00\x00\x00\x70\x00\x00\x00\x00\x00\x00\x00\x14\x00\x14\x00"
      "\x00\x00\x00\x00\x28\x00\x04\x00\x00\x00\x00\x00\x00\x01\x00\x00\xf0\x12"
      "\x03\xf8\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x7c\x00\x00\x00"
      "\x14\x00\x14\x00\x00\x00\x00\x00\x28\x00\x04\x00\x00\x00\x00\x00\x01\x01"
      "\x00\x00\x51\x24\xb3\x00\x01\x01\x00\x00\x80\x00\x00\x00\x00\x00\x00\x00"
      "\x7c\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x02\x00"
      "\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      736);
  *(uint64_t*)0x200003d0 = 0x2e0;
  *(uint64_t*)0x200003d8 = 0x63e0;
  *(uint64_t*)0x200003e0 = 0x20012100;
  memcpy(
      (void*)0x20012100,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x01\x00\x38\x00"
      "\x01\x00\x98\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x0a\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x03\x00\x50\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x02\x00"
      "\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00"
      "\x00\x00\x07\x03\x24\x00\x55\x00\x70\x00\x43\x00\x61\x00\x73\x00\x65\x00"
      "\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00\x01\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x1f\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00"
      "\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x21\x20\x89\x00\x00\x00\x00\x00"
      "\x80\x00\x00\x00\x48\x00\x00\x00\x00\x05\x18\x00\x00\x00\x02\x00\x20\x00"
      "\x00\x00\x28\x00\x00\x00\x24\x00\x49\x00\x6e\x00\x66\x00\x6f\x00\x00\x00"
      "\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x0c\x69\x1b\x6b\x77\x7e"
      "\xdc\xda\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      448);
  *(uint64_t*)0x200003e8 = 0x1c0;
  *(uint64_t*)0x200003f0 = 0x67e0;
  *(uint64_t*)0x200003f8 = 0x20012300;
  memcpy((void*)0x20012300,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000400 = 0x20;
  *(uint64_t*)0x20000408 = 0x69e0;
  *(uint64_t*)0x20000410 = 0x20001240;
  memcpy(
      (void*)0x20001240,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x01\x00\x38\x00"
      "\x03\x00\x80\x02\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x0b\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x50\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x10\x00\x00"
      "\x00\x00\x07\x03\x24\x00\x45\x00\x78\x00\x74\x00\x65\x00\x6e\x00\x64\x00"
      "\x90\x00\x00\x00\x78\x01\x00\x00\x00\x04\x18\x00\x00\x00\x02\x00\x58\x01"
      "\x00\x00\x20\x00\x00\x00\x24\x00\x49\x00\x33\x00\x30\x00\x30\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x10\x00\x00\x00\x48\x01"
      "\x00\x00\x48\x01\x00\x00\x00\x00\x00\x00\x19\x00\x00\x00\x00\x00\x01\x00"
      "\x60\x00\x4e\x00\x00\x00\x00\x00\x0b\x00\x00\x00\x00\x00\x0b\x00\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00"
      "\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x20\x00\x00\x00\x00"
      "\x06\x03\x24\x00\x4f\x00\x62\x00\x6a\x00\x49\x00\x64\x00\x00\x00\x18\x00"
      "\x00\x00\x00\x00\x01\x00\x60\x00\x4e\x00\x00\x00\x00\x00\x0b\x00\x00\x00"
      "\x00\x00\x0b\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x26\x00"
      "\x00\x20\x00\x00\x00\x00\x06\x03\x24\x00\x51\x00\x75\x00\x6f\x00\x74\x00"
      "\x61\x00\x02\x00\x1a\x00\x00\x00\x00\x00\x01\x00\x68\x00\x52\x00\x00\x00"
      "\x00\x00\x0b\x00\x00\x00\x00\x00\x0b\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x26\x00\x00\x20\x00\x00\x00\x00\x08\x03\x24\x00\x52\x00"
      "\x65\x00\x70\x00\x61\x00\x72\x00\x73\x00\x65\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x02\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00",
      672);
  *(uint64_t*)0x20000418 = 0x2a0;
  *(uint64_t*)0x20000420 = 0x6be0;
  *(uint64_t*)0x20000428 = 0x20012700;
  memcpy(
      (void*)0x20012700,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0c\x00\x00\x00\x38\x00"
      "\x01\x00\x20\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x0c\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00"
      "\x00\x00\x80\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x64\x00\x00\x00"
      "\x18\x00\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00\x00\x00\x00\x00"
      "\x00\x00\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00"
      "\x9f\x01\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00"
      "\x18\x00\x9f\x01\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00"
      "\x20\x02\x00\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x02"
      "\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00\x00\x00"
      "\x80\x00\x00\x00\x18\x00\x00\x00\x00\x00\x18\x00\x00\x00\x01\x00\x00\x00"
      "\x00\x00\x18\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
      320);
  *(uint64_t*)0x20000430 = 0x140;
  *(uint64_t*)0x20000438 = 0x6fe0;
  *(uint64_t*)0x20000440 = 0x20012900;
  memcpy((void*)0x20012900,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\xff\xff\xff"
         "\xff\xff\x00\x00\x00\x00\xff\xfe\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000448 = 0x20;
  *(uint64_t*)0x20000450 = 0x71e0;
  *(uint64_t*)0x20000458 = 0x20012a00;
  memcpy(
      (void*)0x20012a00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0d\x00\x00\x00\x38\x00"
      "\x01\x00\x20\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x0d\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00"
      "\x00\x00\x80\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x64\x00\x00\x00"
      "\x18\x00\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00\x00\x00\x00\x00"
      "\x00\x00\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00"
      "\x9f\x01\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00"
      "\x18\x00\x9f\x01\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00"
      "\x20\x02\x00\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x02"
      "\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00\x00\x00"
      "\x80\x00\x00\x00\x18\x00\x00\x00\x00\x00\x18\x00\x00\x00\x01\x00\x00\x00"
      "\x00\x00\x18\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
      320);
  *(uint64_t*)0x20000460 = 0x140;
  *(uint64_t*)0x20000468 = 0x73e0;
  *(uint64_t*)0x20000470 = 0x20012c00;
  memcpy((void*)0x20012c00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000478 = 0x20;
  *(uint64_t*)0x20000480 = 0x75e0;
  *(uint64_t*)0x20000488 = 0x20012d00;
  memcpy(
      (void*)0x20012d00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0e\x00\x00\x00\x38\x00"
      "\x01\x00\x20\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x0e\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00"
      "\x00\x00\x80\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x64\x00\x00\x00"
      "\x18\x00\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00\x00\x00\x00\x00"
      "\x00\x00\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00"
      "\x9f\x01\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00"
      "\x18\x00\x9f\x01\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00"
      "\x20\x02\x00\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x02"
      "\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00\x00\x00"
      "\x80\x00\x00\x00\x18\x00\x00\x00\x00\x00\x18\x00\x00\x00\x01\x00\x00\x00"
      "\x00\x00\x18\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
      320);
  *(uint64_t*)0x20000490 = 0x140;
  *(uint64_t*)0x20000498 = 0x77e0;
  *(uint64_t*)0x200004a0 = 0x20012f00;
  memcpy((void*)0x20012f00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200004a8 = 0x20;
  *(uint64_t*)0x200004b0 = 0x79e0;
  *(uint64_t*)0x200004b8 = 0x20013000;
  memcpy(
      (void*)0x20013000,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0f\x00\x00\x00\x38\x00"
      "\x01\x00\x20\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x0f\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00"
      "\x00\x00\x80\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x64\x00\x00\x00"
      "\x18\x00\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00\x00\x00\x00\x00"
      "\x00\x00\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00"
      "\x9f\x01\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00"
      "\x18\x00\x9f\x01\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00"
      "\x20\x02\x00\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x02"
      "\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00\x00\x00"
      "\x80\x00\x00\x00\x18\x00\x00\x00\x00\x00\x18\x00\x00\x00\x01\x00\x00\x00"
      "\x00\x00\x18\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
      320);
  *(uint64_t*)0x200004c0 = 0x140;
  *(uint64_t*)0x200004c8 = 0x7be0;
  *(uint64_t*)0x200004d0 = 0x20013200;
  memcpy((void*)0x20013200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200004d8 = 0x20;
  *(uint64_t*)0x200004e0 = 0x7de0;
  *(uint64_t*)0x200004e8 = 0x20013300;
  memcpy(
      (void*)0x20013300,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x200004f0 = 0xc0;
  *(uint64_t*)0x200004f8 = 0x7fe0;
  *(uint64_t*)0x20000500 = 0x20013400;
  memcpy((void*)0x20013400,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000508 = 0x20;
  *(uint64_t*)0x20000510 = 0x81e0;
  *(uint64_t*)0x20000518 = 0x20013500;
  memcpy(
      (void*)0x20013500,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x11\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x20000520 = 0xc0;
  *(uint64_t*)0x20000528 = 0x83e0;
  *(uint64_t*)0x20000530 = 0x20013600;
  memcpy((void*)0x20013600,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000538 = 0x20;
  *(uint64_t*)0x20000540 = 0x85e0;
  *(uint64_t*)0x20000548 = 0x20013700;
  memcpy(
      (void*)0x20013700,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x12\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x20000550 = 0xc0;
  *(uint64_t*)0x20000558 = 0x87e0;
  *(uint64_t*)0x20000560 = 0x20013800;
  memcpy((void*)0x20013800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000568 = 0x20;
  *(uint64_t*)0x20000570 = 0x89e0;
  *(uint64_t*)0x20000578 = 0x20013900;
  memcpy(
      (void*)0x20013900,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x13\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x20000580 = 0xc0;
  *(uint64_t*)0x20000588 = 0x8be0;
  *(uint64_t*)0x20000590 = 0x20013a00;
  memcpy((void*)0x20013a00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000598 = 0x20;
  *(uint64_t*)0x200005a0 = 0x8de0;
  *(uint64_t*)0x200005a8 = 0x20013b00;
  memcpy(
      (void*)0x20013b00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x14\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x200005b0 = 0xc0;
  *(uint64_t*)0x200005b8 = 0x8fe0;
  *(uint64_t*)0x200005c0 = 0x20013c00;
  memcpy((void*)0x20013c00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200005c8 = 0x20;
  *(uint64_t*)0x200005d0 = 0x91e4;
  *(uint64_t*)0x200005d8 = 0x20013d00;
  memcpy(
      (void*)0x20013d00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x15\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x200005e0 = 0xc0;
  *(uint64_t*)0x200005e8 = 0x93e0;
  *(uint64_t*)0x200005f0 = 0x20013e00;
  memcpy((void*)0x20013e00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200005f8 = 0x20;
  *(uint64_t*)0x20000600 = 0x95e0;
  *(uint64_t*)0x20000608 = 0x20013f00;
  memcpy(
      (void*)0x20013f00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x16\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x20000610 = 0xc0;
  *(uint64_t*)0x20000618 = 0x97e0;
  *(uint64_t*)0x20000620 = 0x20014000;
  memcpy((void*)0x20014000,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000628 = 0x20;
  *(uint64_t*)0x20000630 = 0x99e0;
  *(uint64_t*)0x20000638 = 0x20014100;
  memcpy(
      (void*)0x20014100,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x17\x00\x00\x00\x38\x00"
      "\x00\x00\x88\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      192);
  *(uint64_t*)0x20000640 = 0xc0;
  *(uint64_t*)0x20000648 = 0x9be0;
  *(uint64_t*)0x20000650 = 0x20014200;
  memcpy((void*)0x20014200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000658 = 0x20;
  *(uint64_t*)0x20000660 = 0x9de0;
  *(uint64_t*)0x20000668 = 0x20014300;
  memcpy(
      (void*)0x20014300,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x0d\x00\x70\x02\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x18\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x26\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x4e\x00\x00\x00\x18\x00\x01\x00\x0b\x00\x00\x00\x00\x00\x0b\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x20\x00\x00"
      "\x00\x00\x06\x03\x24\x00\x51\x00\x75\x00\x6f\x00\x74\x00\x61\x00\x00\x00"
      "\x90\x00\x00\x00\x78\x00\x00\x00\x00\x02\x18\x00\x00\x00\x03\x00\x58\x00"
      "\x00\x00\x20\x00\x00\x00\x24\x00\x4f\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x11\x00\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x10\x00\x00\x00\x48\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x20\x00\x04\x00\x00\x00\x00\x00"
      "\x28\x00\x10\x00\x00\x00\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00"
      "\x00\x00\x20\x02\x00\x00\x00\x01\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x10\x00\x00\x00\x02\x00\x00\x00\x90\x00\x00\x00\xf0\x00"
      "\x00\x00\x00\x02\x18\x00\x00\x00\x02\x00\xd0\x00\x00\x00\x20\x00\x00\x00"
      "\x24\x00\x51\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x10"
      "\x00\x00\x01\x00\x00\x00\x10\x00\x00\x00\xc0\x00\x00\x00\xc0\x00\x00\x00"
      "\x00\x00\x00\x00\x14\x00\x30\x00\x00\x00\x00\x00\x48\x00\x04\x00\x00\x00"
      "\x00\x00\x01\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\xff\xff\xff\xff\xff\xff"
      "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x02\x00\x14\x00\x40\x00\x00\x00\x00\x00\x58\x00\x04\x00\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\xff\xff\xff\xff\xff\xff"
      "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x02\x00\x00\x00"
      "\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00",
      672);
  *(uint64_t*)0x20000670 = 0x2a0;
  *(uint64_t*)0x20000678 = 0x9fe0;
  *(uint64_t*)0x20000680 = 0x20014600;
  memcpy(
      (void*)0x20014600,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x0d\x00\x58\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x19\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x26\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x4e\x00\x00\x00\x18\x00\x01\x00\x0b\x00\x00\x00\x00\x00\x0b\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x20\x00\x00"
      "\x00\x00\x06\x03\x24\x00\x4f\x00\x62\x00\x6a\x00\x49\x00\x64\x00\x00\x00"
      "\x90\x00\x00\x00\x50\x00\x00\x00\x00\x02\x18\x00\x00\x00\x02\x00\x30\x00"
      "\x00\x00\x20\x00\x00\x00\x24\x00\x4f\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x13\x00\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x10\x00\x00\x00\x20\x00"
      "\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x10\x00\x00\x00\x02\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00",
      384);
  *(uint64_t*)0x20000688 = 0x180;
  *(uint64_t*)0x20000690 = 0xa3e0;
  *(uint64_t*)0x20000698 = 0x20014800;
  memcpy((void*)0x20014800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200006a0 = 0x20;
  *(uint64_t*)0x200006a8 = 0xa5e0;
  *(uint64_t*)0x200006b0 = 0x20014900;
  memcpy(
      (void*)0x20014900,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x0d\x00\x60\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x03\x00\x00\x00\x1a\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00"
      "\x18\x00\x00\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x26\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x30\x00\x00\x00\x70\x00\x00\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x52\x00\x00\x00\x18\x00\x01\x00\x0b\x00\x00\x00\x00\x00\x0b\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x20\x00\x00"
      "\x00\x00\x08\x03\x24\x00\x52\x00\x65\x00\x70\x00\x61\x00\x72\x00\x73\x00"
      "\x65\x00\x00\x00\x00\x00\x00\x00\x90\x00\x00\x00\x50\x00\x00\x00\x00\x02"
      "\x18\x00\x00\x00\x02\x00\x30\x00\x00\x00\x20\x00\x00\x00\x24\x00\x52\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x13\x00\x00\x00\x00\x10\x00\x00\x01\x00"
      "\x00\x00\x10\x00\x00\x00\x20\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x02\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00",
      384);
  *(uint64_t*)0x200006b8 = 0x180;
  *(uint64_t*)0x200006c0 = 0xa7e0;
  *(uint64_t*)0x200006c8 = 0x20014b00;
  memcpy((void*)0x20014b00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200006d0 = 0x20;
  *(uint64_t*)0x200006d8 = 0xa9e0;
  *(uint64_t*)0x200006e0 = 0x20014c00;
  memcpy((void*)0x20014c00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x1b\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x200006e8 = 0x60;
  *(uint64_t*)0x200006f0 = 0xabe0;
  *(uint64_t*)0x200006f8 = 0x20014d00;
  memcpy((void*)0x20014d00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000700 = 0x20;
  *(uint64_t*)0x20000708 = 0xade0;
  *(uint64_t*)0x20000710 = 0x20014e00;
  memcpy((void*)0x20014e00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x1c\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000718 = 0x60;
  *(uint64_t*)0x20000720 = 0xafe0;
  *(uint64_t*)0x20000728 = 0x20014f00;
  memcpy((void*)0x20014f00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000730 = 0x20;
  *(uint64_t*)0x20000738 = 0xb1e0;
  *(uint64_t*)0x20000740 = 0x20015000;
  memcpy((void*)0x20015000,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x1d\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000748 = 0x60;
  *(uint64_t*)0x20000750 = 0xb3e0;
  *(uint64_t*)0x20000758 = 0x20015100;
  memcpy((void*)0x20015100,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000760 = 0x20;
  *(uint64_t*)0x20000768 = 0xb5e0;
  *(uint64_t*)0x20000770 = 0x20015200;
  memcpy((void*)0x20015200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x1e\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000778 = 0x60;
  *(uint64_t*)0x20000780 = 0xb7e0;
  *(uint64_t*)0x20000788 = 0x20015300;
  memcpy((void*)0x20015300,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000790 = 0x20;
  *(uint64_t*)0x20000798 = 0xb9e0;
  *(uint64_t*)0x200007a0 = 0x200016c0;
  memcpy(
      (void*)0x200016c0,
      "\x00\x00\x00\x00\xd7\x44\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x24\xec\x18\x83\xae\xab\x51\x08"
      "\x15\x00\x46\x49\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x01\x00\x00\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x1f\x00\x00\x00\x02\x00\x00\x00"
      "\x00\x00\x00\x00\xff\xff\xb3\xdb\x93\xea\x6a\x6d\x06\x62\x3b\x4b\x97\x8e"
      "\x50\x91\x12\x99\x48\xa2\x14\x99\x71\x6c\xd5\xf9\x53\x5c\x5c\x54\x7e\x6f"
      "\xb4\x17\xea\xfa\xa8\xb7\xc2\x51\x17\x47\x92\x01\x59\x7d\xd7\x6a\x8a\x76"
      "\xea\xb6\xe9\x7c\x45\xdd\x12\x3f\x61\xf2\x59\xbe\xd3\x83\x44\x0e\x41\x31"
      "\x83\x2d\x0a\xc1\x13\xa0\xfe\xd6\x53\xe1\xf3\x13\x2c\xb5\x06\x9d\x4d\x2c"
      "\xe8\xe1\x7b\x9b\xfc\x51\x9e\x83\x1d\x55\x5c\x14\x4e\xaa\x99\x09\x53\x06"
      "\xd3\xe0\x4d\xc9\xfe\x79\x79\x88\xb5\x80\xa3\x35\x9b\x4c\x3d\xe7\x86\xab"
      "\x95\x4d\x49\xe5\x2f\xc8\x1d\x14\xd3\xf1\x3b\x0d\x9d\x30\x36\xda\xec\xd5"
      "\xa8\xc3\xa2\xd5\xd6\x60\xc2\x4b\xef\x22\x63\xd2\xe8\xe1\x81\x31\x84\xf7"
      "\xec\xdb\xf7\x47\x97\x8e\x0c\xc0\x39\x30\xff\x4c\x8f\x28\x6b",
      267);
  *(uint64_t*)0x200007a8 = 0x10b;
  *(uint64_t*)0x200007b0 = 0xbbe0;
  *(uint64_t*)0x200007b8 = 0x20015500;
  memcpy((void*)0x20015500,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200007c0 = 0x20;
  *(uint64_t*)0x200007c8 = 0xbde0;
  *(uint64_t*)0x200007d0 = 0x20001500;
  memcpy(
      (void*)0x20001500,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x38\x00"
      "\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x20\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x4c\x01\x91\x26\x5f\xe0\x44\x40\x94\x8f\x90\x4b"
      "\x4e\xca\xdb\x58\x31\xfb\xef\x75\x8a\xc2\x21\xea\xa2\xfd\x9a\x2f\x3f\xdc"
      "\x6f\x60\xc6\xce\xe2\x4f\xab\x73\x6e\x07\x08\x52\x1c\xe5\x46\x4b\xb1\xc5"
      "\x9d\xa3\x06\xf8\x6f\xfb\xab\x87\x7c\xed\x67\x56\x78\x75\x2a\x5a\x7e\xec"
      "\xac\x73\x01\x70\x9a\xaf\xa0\xb9\xa5\xeb\x12\xed\x13\xcf\xc5\x21\xd7\x14"
      "\x4f\x4d\xeb\xfe\x9b\xfb\xfa\x31\xcf\xbf\x40\x73\xb1\x88\xfb\x61\xc1\xaf"
      "\x8a\xef\x59\xb7\xb9\x6b\xd9\xc6\xfe\xc6\x25\xda\x16\xb4\xe3\xa5\xb3\xc8"
      "\xd9\x0f\x80\x8e\xe6\x7b\x47\x58\xf2\x87\x9a\xd0\x4c\x96\x4d\x98\x5c\xca"
      "\xbb\x95\x18\x16\x1b\xe5\xa1\x5e\x7d\x54\xe8\x10\x34\x67\x6c\x13\x0e\x3a"
      "\x40\x0b\x87\x2a\x38\xaf\x16\x76\xac\x30\xca\x75\xb7\xae\x97\x12\x32\x7a"
      "\x91\x7c\x0d\xa0\x2e\x9a\xad\x4c\xea\x7a\x79\xf3\x7c\x98\xa8\x5f\xde\x7d"
      "\xe6\x09\x86\xaa\xfe\x3f\x94\xc9\xd0\x7c\x03\x34\xb7\xa7\xa7\x63\x6e\x20"
      "\x49\x1b\x8b\x24\x09\x4d\x54\x7c\x58\x4e\x02\xad\x6d\x27\x91\x61\x6d\xf1"
      "\x09\x57\x7d\x28\xa2\xaa\x00\x43\x53\x93\xb3\x79\xe5\xcb\xb0\x43\x21\x81"
      "\x15\xc9\xf7\xfb\x6d\x1b\xe5\x02\x9b\x9b\xd1\xc2\xdd\xb6\xc1\xcd\xd3\xe2"
      "\xe0\x43\x80\x52\xc3\x84\x31\xc7\x3b\xf2\x35\x27\x5d\xba\x7f\x82\xce\xf7"
      "\x16\x31\x74\x27\x8e\xfb\x5f\x7f\xde\x78\xb6\xf1\x0a\xe3\xc9\xf7\xd9\x97"
      "\x82\xb4\x62\xcf\xfd\xe4\xd5\xbe\x4d\x5f\xcd\xd7\xd8\x01\x87\x5e\x69\x09"
      "\x1f\x0c\xa1\x90\xf9\x1f\xf2\x36\x15\x2a\x76\x83\x63\xb3\x4f\x04\x4c\xc2"
      "\x7d\x62\x26\x19\x3b\x20\x37\x25\x27\x81\x74\xc0\xcd",
      445);
  *(uint64_t*)0x200007d8 = 0x1bd;
  *(uint64_t*)0x200007e0 = 0xbfe0;
  *(uint64_t*)0x200007e8 = 0x20015700;
  memcpy((void*)0x20015700,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200007f0 = 0x20;
  *(uint64_t*)0x200007f8 = 0xc1e0;
  *(uint64_t*)0x20000800 = 0x20015800;
  memcpy((void*)0x20015800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x21\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000808 = 0x60;
  *(uint64_t*)0x20000810 = 0xc3e0;
  *(uint64_t*)0x20000818 = 0x20015900;
  memcpy((void*)0x20015900,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000820 = 0x20;
  *(uint64_t*)0x20000828 = 0xc5e0;
  *(uint64_t*)0x20000830 = 0x20015a00;
  memcpy((void*)0x20015a00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x22\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000838 = 0x60;
  *(uint64_t*)0x20000840 = 0xc7e0;
  *(uint64_t*)0x20000848 = 0x20015b00;
  memcpy((void*)0x20015b00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000850 = 0x20;
  *(uint64_t*)0x20000858 = 0xc9e0;
  *(uint64_t*)0x20000860 = 0x20015c00;
  memcpy((void*)0x20015c00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x23\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000868 = 0x60;
  *(uint64_t*)0x20000870 = 0xcbe0;
  *(uint64_t*)0x20000878 = 0x20015d00;
  memcpy((void*)0x20015d00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000880 = 0x20;
  *(uint64_t*)0x20000888 = 0xcde0;
  *(uint64_t*)0x20000890 = 0x20015e00;
  memcpy((void*)0x20015e00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x24\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000898 = 0x60;
  *(uint64_t*)0x200008a0 = 0xcfe0;
  *(uint64_t*)0x200008a8 = 0x20015f00;
  memcpy((void*)0x20015f00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x50\x30\xb9\xf7\x6c\xda\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         32);
  *(uint64_t*)0x200008b0 = 0x20;
  *(uint64_t*)0x200008b8 = 0xd1e0;
  *(uint64_t*)0x200008c0 = 0x20016000;
  memcpy((void*)0x20016000,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x25\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x200008c8 = 0x60;
  *(uint64_t*)0x200008d0 = 0xd3e0;
  *(uint64_t*)0x200008d8 = 0x20016100;
  memcpy((void*)0x20016100,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200008e0 = 0x20;
  *(uint64_t*)0x200008e8 = 0xd5e0;
  *(uint64_t*)0x200008f0 = 0x20016200;
  memcpy((void*)0x20016200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x200008f8 = 0x60;
  *(uint64_t*)0x20000900 = 0xd7e0;
  *(uint64_t*)0x20000908 = 0x20016300;
  memcpy((void*)0x20016300,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000910 = 0x20;
  *(uint64_t*)0x20000918 = 0xd9e0;
  *(uint64_t*)0x20000920 = 0x20016400;
  memcpy((void*)0x20016400,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x27\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000928 = 0x60;
  *(uint64_t*)0x20000930 = 0xdbe0;
  *(uint64_t*)0x20000938 = 0x20016500;
  memcpy((void*)0x20016500,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000940 = 0x20;
  *(uint64_t*)0x20000948 = 0xdde0;
  *(uint64_t*)0x20000950 = 0x20016600;
  memcpy((void*)0x20016600,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x28\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000958 = 0x60;
  *(uint64_t*)0x20000960 = 0xdfe0;
  *(uint64_t*)0x20000968 = 0x20016700;
  memcpy((void*)0x20016700,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000970 = 0x20;
  *(uint64_t*)0x20000978 = 0xe1e0;
  *(uint64_t*)0x20000980 = 0x20016800;
  memcpy((void*)0x20016800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x29\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000988 = 0x60;
  *(uint64_t*)0x20000990 = 0xe3e0;
  *(uint64_t*)0x20000998 = 0x20016900;
  memcpy((void*)0x20016900,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200009a0 = 0x20;
  *(uint64_t*)0x200009a8 = 0xe5e0;
  *(uint64_t*)0x200009b0 = 0x20016a00;
  memcpy((void*)0x20016a00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x2a\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x200009b8 = 0x60;
  *(uint64_t*)0x200009c0 = 0xe7e0;
  *(uint64_t*)0x200009c8 = 0x20016b00;
  memcpy((void*)0x20016b00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x200009d0 = 0x20;
  *(uint64_t*)0x200009d8 = 0xe9e0;
  *(uint64_t*)0x200009e0 = 0x20016c00;
  memcpy((void*)0x20016c00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x2b\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x200009e8 = 0x60;
  *(uint64_t*)0x200009f0 = 0xebe0;
  *(uint64_t*)0x200009f8 = 0x20016d00;
  memcpy((void*)0x20016d00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000a00 = 0x20;
  *(uint64_t*)0x20000a08 = 0xede0;
  *(uint64_t*)0x20000a10 = 0x20016e00;
  memcpy((void*)0x20016e00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x2c\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000a18 = 0x60;
  *(uint64_t*)0x20000a20 = 0xefe0;
  *(uint64_t*)0x20000a28 = 0x20016f00;
  memcpy((void*)0x20016f00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000a30 = 0x20;
  *(uint64_t*)0x20000a38 = 0xf1e0;
  *(uint64_t*)0x20000a40 = 0x20017000;
  memcpy((void*)0x20017000,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x2d\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000a48 = 0x60;
  *(uint64_t*)0x20000a50 = 0xf3e0;
  *(uint64_t*)0x20000a58 = 0x20017100;
  memcpy((void*)0x20017100,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000a60 = 0x20;
  *(uint64_t*)0x20000a68 = 0xf5e0;
  *(uint64_t*)0x20000a70 = 0x20017200;
  memcpy((void*)0x20017200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x2e\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000a78 = 0x60;
  *(uint64_t*)0x20000a80 = 0xf7e0;
  *(uint64_t*)0x20000a88 = 0x20017300;
  memcpy((void*)0x20017300,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000a90 = 0x20;
  *(uint64_t*)0x20000a98 = 0xf9e0;
  *(uint64_t*)0x20000aa0 = 0x20017400;
  memcpy((void*)0x20017400,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x2f\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000aa8 = 0x60;
  *(uint64_t*)0x20000ab0 = 0xfbe0;
  *(uint64_t*)0x20000ab8 = 0x20017500;
  memcpy((void*)0x20017500,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000ac0 = 0x20;
  *(uint64_t*)0x20000ac8 = 0xfde0;
  *(uint64_t*)0x20000ad0 = 0x20017600;
  memcpy((void*)0x20017600,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000ad8 = 0x60;
  *(uint64_t*)0x20000ae0 = 0xffe0;
  *(uint64_t*)0x20000ae8 = 0x20017700;
  memcpy((void*)0x20017700,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000af0 = 0x20;
  *(uint64_t*)0x20000af8 = 0x101e0;
  *(uint64_t*)0x20000b00 = 0x20017800;
  memcpy((void*)0x20017800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x31\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000b08 = 0x60;
  *(uint64_t*)0x20000b10 = 0x103e0;
  *(uint64_t*)0x20000b18 = 0x20017900;
  memcpy((void*)0x20017900,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000b20 = 0x20;
  *(uint64_t*)0x20000b28 = 0x105e0;
  *(uint64_t*)0x20000b30 = 0x20017a00;
  memcpy((void*)0x20017a00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x32\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000b38 = 0x60;
  *(uint64_t*)0x20000b40 = 0x107e0;
  *(uint64_t*)0x20000b48 = 0x20017b00;
  memcpy((void*)0x20017b00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000b50 = 0x20;
  *(uint64_t*)0x20000b58 = 0x109e0;
  *(uint64_t*)0x20000b60 = 0x20017c00;
  memcpy((void*)0x20017c00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x33\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000b68 = 0x60;
  *(uint64_t*)0x20000b70 = 0x10be0;
  *(uint64_t*)0x20000b78 = 0x20017d00;
  memcpy((void*)0x20017d00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000b80 = 0x20;
  *(uint64_t*)0x20000b88 = 0x10de0;
  *(uint64_t*)0x20000b90 = 0x20017e00;
  memcpy((void*)0x20017e00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x34\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000b98 = 0x60;
  *(uint64_t*)0x20000ba0 = 0x10fe0;
  *(uint64_t*)0x20000ba8 = 0x20017f00;
  memcpy((void*)0x20017f00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000bb0 = 0x20;
  *(uint64_t*)0x20000bb8 = 0x111e0;
  *(uint64_t*)0x20000bc0 = 0x20018000;
  memcpy((void*)0x20018000,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x35\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000bc8 = 0x60;
  *(uint64_t*)0x20000bd0 = 0x113e0;
  *(uint64_t*)0x20000bd8 = 0x20018100;
  memcpy((void*)0x20018100,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000be0 = 0x20;
  *(uint64_t*)0x20000be8 = 0x115e0;
  *(uint64_t*)0x20000bf0 = 0x20018200;
  memcpy((void*)0x20018200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x36\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000bf8 = 0x60;
  *(uint64_t*)0x20000c00 = 0x117e0;
  *(uint64_t*)0x20000c08 = 0x20018300;
  memcpy((void*)0x20018300,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000c10 = 0x20;
  *(uint64_t*)0x20000c18 = 0x119e0;
  *(uint64_t*)0x20000c20 = 0x20018400;
  memcpy((void*)0x20018400,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x37\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000c28 = 0x60;
  *(uint64_t*)0x20000c30 = 0x11be0;
  *(uint64_t*)0x20000c38 = 0x20018500;
  memcpy((void*)0x20018500,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000c40 = 0x20;
  *(uint64_t*)0x20000c48 = 0x11de0;
  *(uint64_t*)0x20000c50 = 0x20018600;
  memcpy((void*)0x20018600,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x38\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000c58 = 0x60;
  *(uint64_t*)0x20000c60 = 0x11fe0;
  *(uint64_t*)0x20000c68 = 0x20018700;
  memcpy((void*)0x20018700,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000c70 = 0x20;
  *(uint64_t*)0x20000c78 = 0x121e0;
  *(uint64_t*)0x20000c80 = 0x20018800;
  memcpy((void*)0x20018800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x39\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000c88 = 0x60;
  *(uint64_t*)0x20000c90 = 0x123e0;
  *(uint64_t*)0x20000c98 = 0x20018900;
  memcpy((void*)0x20018900,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000ca0 = 0x20;
  *(uint64_t*)0x20000ca8 = 0x125e0;
  *(uint64_t*)0x20000cb0 = 0x20018a00;
  memcpy((void*)0x20018a00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x3a\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000cb8 = 0x60;
  *(uint64_t*)0x20000cc0 = 0x127e0;
  *(uint64_t*)0x20000cc8 = 0x20018b00;
  memcpy((void*)0x20018b00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000cd0 = 0x20;
  *(uint64_t*)0x20000cd8 = 0x129e0;
  *(uint64_t*)0x20000ce0 = 0x20018c00;
  memcpy((void*)0x20018c00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x3b\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000ce8 = 0x60;
  *(uint64_t*)0x20000cf0 = 0x12be0;
  *(uint64_t*)0x20000cf8 = 0x20018d00;
  memcpy((void*)0x20018d00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000d00 = 0x20;
  *(uint64_t*)0x20000d08 = 0x12de0;
  *(uint64_t*)0x20000d10 = 0x20018e00;
  memcpy((void*)0x20018e00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x3c\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000d18 = 0x60;
  *(uint64_t*)0x20000d20 = 0x12fe0;
  *(uint64_t*)0x20000d28 = 0x20018f00;
  memcpy((void*)0x20018f00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000d30 = 0x20;
  *(uint64_t*)0x20000d38 = 0x131e0;
  *(uint64_t*)0x20000d40 = 0x20019000;
  memcpy((void*)0x20019000,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x3d\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000d48 = 0x60;
  *(uint64_t*)0x20000d50 = 0x133e0;
  *(uint64_t*)0x20000d58 = 0x20019100;
  memcpy((void*)0x20019100,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000d60 = 0x20;
  *(uint64_t*)0x20000d68 = 0x135e0;
  *(uint64_t*)0x20000d70 = 0x20019200;
  memcpy((void*)0x20019200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x3e\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000d78 = 0x60;
  *(uint64_t*)0x20000d80 = 0x137e0;
  *(uint64_t*)0x20000d88 = 0x20019300;
  memcpy((void*)0x20019300,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000d90 = 0x20;
  *(uint64_t*)0x20000d98 = 0x139e0;
  *(uint64_t*)0x20000da0 = 0x20019400;
  memcpy((void*)0x20019400,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49"
         "\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00"
         "\x00\x38\x00\x00\x00\x40\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x3f\x00\x00\x00\x02\x00\x00\x00\x00"
         "\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000da8 = 0x60;
  *(uint64_t*)0x20000db0 = 0x13be0;
  *(uint64_t*)0x20000db8 = 0x20019500;
  memcpy((void*)0x20019500,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00",
         32);
  *(uint64_t*)0x20000dc0 = 0x20;
  *(uint64_t*)0x20000dc8 = 0x13de0;
  *(uint64_t*)0x20000dd0 = 0x20019600;
  memcpy(
      (void*)0x20019600,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x03\x00\x68\x02\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x40\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x6a\x0a\x79\x00\xc8\x8d\xd6\x01\x12\x33\x79\x00\xc8\x8d"
      "\xd6\x01\x12\x33\x79\x00\xc8\x8d\xd6\x01\x6a\x0a\x79\x00\xc8\x8d\xd6\x01"
      "\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x68\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x4c\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x6a\x0a\x79\x00\xc8\x8d"
      "\xd6\x01\x6a\x0a\x79\x00\xc8\x8d\xd6\x01\x6a\x0a\x79\x00\xc8\x8d\xd6\x01"
      "\x6a\x0a\x79\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x20\x00\x00\x10\x00\x00\x00\x00\x05\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x30\x00\x00\x00\x00\x00\x50\x00\x00\x00\x68\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x50\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x04\x80\x14\x00\x00\x00\x24\x00\x00\x00\x00\x00\x00\x00\x34\x00"
      "\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x02\x00"
      "\x1c\x00\x01\x00\x00\x00\x00\x03\x14\x00\xff\x01\x1f\x00\x01\x01\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x90\x00\x00\x00\x10\x01\x00\x00\x00\x04"
      "\x18\x00\x00\x00\x02\x00\xf0\x00\x00\x00\x20\x00\x00\x00\x24\x00\x49\x00"
      "\x33\x00\x30\x00\x30\x00\x00\x00\x01\x00\x00\x00\x00\x10\x00\x00\x01\x00"
      "\x00\x00\x10\x00\x00\x00\xe0\x00\x00\x00\xe0\x00\x00\x00\x00\x00\x00\x00"
      "\x41\x00\x00\x00\x00\x00\x01\x00\x60\x00\x4c\x00\x00\x00\x00\x00\x40\x00"
      "\x00\x00\x00\x00\x01\x00\xee\x20\x79\x00\xc8\x8d\xd6\x01\x9b\x29\x79\x00"
      "\xc8\x8d\xd6\x01\x9b\x29\x79\x00\xc8\x8d\xd6\x01\xee\x20\x79\x00\xc8\x8d"
      "\xd6\x01\x00\x10\x00\x00\x00\x00\x00\x00\x1a\x04\x00\x00\x00\x00\x00\x00"
      "\x20\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00\x69\x00\x6c\x00\x65\x00"
      "\x30\x00\x00\x00\x00\x00\x42\x00\x00\x00\x00\x00\x01\x00\x60\x00\x4c\x00"
      "\x00\x00\x06\x00\x40\x00\x00\x00\x00\x00\x01\x00\x9d\x32\x79\x00\xc8\x8d"
      "\xd6\x01\x9d\x32\x79\x00\xc8\x8d\xd6\x01\x9d\x32\x79\x00\xc8\x8d\xd6\x01"
      "\x9d\x32\x79\x00\xc8\x8d\xd6\x01\x58\x00\x00\x00\x00\x00\x00\x00\x54\x00"
      "\x00\x00\x00\x00\x00\x00\x24\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x31\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x10\x00\x00\x00\x02\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00",
      672);
  *(uint64_t*)0x20000dd8 = 0x2a0;
  *(uint64_t*)0x20000de0 = 0x13fe0;
  *(uint64_t*)0x20000de8 = 0x20019900;
  memcpy(
      (void*)0x20019900,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x01\x00\xa0\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x41\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\xee\x20\x79\x00\xc8\x8d\xd6\x01\x9b\x29\x79\x00\xc8\x8d"
      "\xd6\x01\x9b\x29\x79\x00\xc8\x8d\xd6\x01\xee\x20\x79\x00\xc8\x8d\xd6\x01"
      "\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x68\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x4c\x00\x00\x00"
      "\x18\x00\x01\x00\x40\x00\x00\x00\x00\x00\x01\x00\xee\x20\x79\x00\xc8\x8d"
      "\xd6\x01\xee\x20\x79\x00\xc8\x8d\xd6\x01\xee\x20\x79\x00\xc8\x8d\xd6\x01"
      "\xee\x20\x79\x00\xc8\x8d\xd6\x01\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x30\x00\x00\x00\x00\x00\x50\x00\x00\x00\x68\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x50\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x04\x80\x14\x00\x00\x00\x24\x00\x00\x00\x00\x00\x00\x00\x34\x00"
      "\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x02\x00"
      "\x1c\x00\x01\x00\x00\x00\x00\x03\x14\x00\xff\x01\x1f\x00\x01\x01\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00"
      "\x40\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00"
      "\x00\x00\x1a\x04\x00\x00\x00\x00\x00\x00\x1a\x04\x00\x00\x00\x00\x00\x00"
      "\x21\x01\x40\x01\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\xff\xff"
      "\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      480);
  *(uint64_t*)0x20000df0 = 0x1e0;
  *(uint64_t*)0x20000df8 = 0x143e0;
  *(uint64_t*)0x20000e00 = 0x20019b00;
  memcpy((void*)0x20019b00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00",
         32);
  *(uint64_t*)0x20000e08 = 0x20;
  *(uint64_t*)0x20000e10 = 0x145e0;
  *(uint64_t*)0x20000e18 = 0x20019c00;
  memcpy(
      (void*)0x20019c00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x01\x00\xc8\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x42\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x9d\x32\x79\x00\xc8\x8d\xd6\x01\x9d\x32\x79\x00\xc8\x8d"
      "\xd6\x01\x9d\x32\x79\x00\xc8\x8d\xd6\x01\x9d\x32\x79\x00\xc8\x8d\xd6\x01"
      "\x24\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x68\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x4c\x00\x00\x00"
      "\x18\x00\x01\x00\x40\x00\x00\x00\x00\x00\x01\x00\x9d\x32\x79\x00\xc8\x8d"
      "\xd6\x01\x9d\x32\x79\x00\xc8\x8d\xd6\x01\x9d\x32\x79\x00\xc8\x8d\xd6\x01"
      "\x9d\x32\x79\x00\xc8\x8d\xd6\x01\x58\x00\x00\x00\x00\x00\x00\x00\x54\x00"
      "\x00\x00\x00\x00\x00\x00\x24\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x31\x00\x00\x00\x00\x00\x50\x00\x00\x00\x68\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x50\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x04\x80\x14\x00\x00\x00\x24\x00\x00\x00\x00\x00\x00\x00\x34\x00"
      "\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x02\x00"
      "\x1c\x00\x01\x00\x00\x00\x00\x03\x14\x00\xff\x01\x1f\x00\x01\x01\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x80\x00\x00\x00\x70\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x02\x00\x54\x00\x00\x00\x18\x00\x00\x00\x49\x6e\x74\x78"
      "\x4c\x4e\x4b\x01\x2f\x00\x74\x00\x6d\x00\x70\x00\x2f\x00\x73\x00\x79\x00"
      "\x7a\x00\x2d\x00\x69\x00\x6d\x00\x61\x00\x67\x00\x65\x00\x67\x00\x65\x00"
      "\x6e\x00\x39\x00\x30\x00\x31\x00\x37\x00\x31\x00\x38\x00\x30\x00\x39\x00"
      "\x34\x00\x2f\x00\x66\x00\x69\x00\x6c\x00\x65\x00\x30\x00\x2f\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x30\x00\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x03\x00",
      544);
  *(uint64_t*)0x20000e20 = 0x220;
  *(uint64_t*)0x20000e28 = 0x147e0;
  *(uint64_t*)0x20000e30 = 0x20019f00;
  memcpy(
      (void*)0x20019f00,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x01\x00\xe0\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x06\x00\x00\x00\x43\x00\x00\x00\x09\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\xce\x36\x79\x00\xc8\x8d\xd6\x01\x7f\x3e\x79\x00\xc8\x8d"
      "\xd6\x01\xec\x46\x79\x00\xc8\x8d\xd6\x01\xce\x36\x79\x00\xc8\x8d\xd6\x01"
      "\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x68\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x4c\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\xce\x36\x79\x00\xc8\x8d"
      "\xd6\x01\xce\x36\x79\x00\xc8\x8d\xd6\x01\xce\x36\x79\x00\xc8\x8d\xd6\x01"
      "\xce\x36\x79\x00\xc8\x8d\xd6\x01\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x31\x00\x00\x00\x00\x00\x50\x00\x00\x00\x68\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x50\x00\x00\x00\x18\x00\x00\x00"
      "\x01\x00\x04\x80\x14\x00\x00\x00\x24\x00\x00\x00\x00\x00\x00\x00\x34\x00"
      "\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x02\x00"
      "\x1c\x00\x01\x00\x00\x00\x00\x03\x14\x00\xff\x01\x1f\x00\x01\x01\x00\x00"
      "\x00\x00\x00\x01\x00\x00\x00\x00\x80\x00\x00\x00\x28\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x02\x00\x0a\x00\x00\x00\x18\x00\x00\x00\x73\x79\x7a\x6b"
      "\x61\x6c\x6c\x65\x72\x73\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x30\x00"
      "\x00\x00\x00\x06\x18\x00\x00\x00\x04\x00\x06\x00\x00\x00\x28\x00\x00\x00"
      "\x78\x00\x61\x00\x74\x00\x74\x00\x72\x00\x31\x00\x00\x00\x00\x00\x78\x61"
      "\x74\x74\x72\x31\x00\x00\x80\x00\x00\x00\x30\x00\x00\x00\x00\x06\x18\x00"
      "\x00\x00\x05\x00\x06\x00\x00\x00\x28\x00\x00\x00\x78\x00\x61\x00\x74\x00"
      "\x74\x00\x72\x00\x32\x00\x00\x00\x00\x00\x78\x61\x74\x74\x72\x32\x00\x00"
      "\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x09\x00",
      544);
  *(uint64_t*)0x20000e38 = 0x220;
  *(uint64_t*)0x20000e40 = 0x14be0;
  *(uint64_t*)0x20000e48 = 0x2001a200;
  memcpy(
      (void*)0x2001a200,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x09\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x02\x00\x38\x00"
      "\x01\x00\x08\x02\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x05\x00\x00\x00\x44\x00\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\xbb\x4d\x79\x00\xc8\x8d\xd6\x01\xf6\x67\x79\x00\xc8\x8d"
      "\xd6\x01\x86\x6f\x79\x00\xc8\x8d\xd6\x01\xbb\x4d\x79\x00\xc8\x8d\xd6\x01"
      "\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x68\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x4c\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\xbb\x4d\x79\x00\xc8\x8d"
      "\xd6\x01\xbb\x4d\x79\x00\xc8\x8d\xd6\x01\xbb\x4d\x79\x00\xc8\x8d\xd6\x01"
      "\xbb\x4d\x79\x00\xc8\x8d\xd6\x01\x00\x30\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x32\x00\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x4c\x00\x00\x00\x18\x00\x01\x00"
      "\x05\x00\x00\x00\x00\x00\x05\x00\xbb\x4d\x79\x00\xc8\x8d\xd6\x01\xf6\x67"
      "\x79\x00\xc8\x8d\xd6\x01\xf6\x67\x79\x00\xc8\x8d\xd6\x01\xbb\x4d\x79\x00"
      "\xc8\x8d\xd6\x01\x00\x30\x00\x00\x00\x00\x00\x00\x28\x23\x00\x00\x00\x00"
      "\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00\x69\x00\x6c\x00"
      "\x65\x00\x33\x00\x00\x00\x00\x00\x50\x00\x00\x00\x68\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x01\x00\x50\x00\x00\x00\x18\x00\x00\x00\x01\x00\x04\x80"
      "\x14\x00\x00\x00\x24\x00\x00\x00\x00\x00\x00\x00\x34\x00\x00\x00\x01\x02"
      "\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x01\x02\x00\x00"
      "\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x02\x00\x1c\x00\x01\x00"
      "\x00\x00\x00\x03\x14\x00\xff\x01\x1f\x00\x01\x01\x00\x00\x00\x00\x00\x01"
      "\x00\x00\x00\x00\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00"
      "\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00"
      "\x40\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x28\x23"
      "\x00\x00\x00\x00\x00\x00\x28\x23\x00\x00\x00\x00\x00\x00\x21\x03\x41\x01"
      "\x00\x00\x0a\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00",
      576);
  *(uint64_t*)0x20000e50 = 0x240;
  *(uint64_t*)0x20000e58 = 0x14fe0;
  *(uint64_t*)0x20000e60 = 0x2001a500;
  memcpy(
      (void*)0x2001a500,
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x46\x49\x4c\x45"
      "\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00"
      "\x01\x00\xe0\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x04\x00\x00\x00\x45\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x10\x00"
      "\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
      "\x18\x00\x00\x00\x1b\x77\x79\x00\xc8\x8d\xd6\x01\x0b\x7b\x79\x00\xc8\x8d"
      "\xd6\x01\x0b\x7b\x79\x00\xc8\x8d\xd6\x01\x1b\x77\x79\x00\xc8\x8d\xd6\x01"
      "\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00"
      "\x00\x00\x70\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x54\x00\x00\x00"
      "\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x1b\x77\x79\x00\xc8\x8d"
      "\xd6\x01\x1b\x77\x79\x00\xc8\x8d\xd6\x01\x1b\x77\x79\x00\xc8\x8d\xd6\x01"
      "\x1b\x77\x79\x00\xc8\x8d\xd6\x01\x68\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x09\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x2e\x00\x63\x00\x6f\x00\x6c\x00\x64\x00\x18\x00"
      "\x00\x00\x50\x00\x00\x00\x68\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00"
      "\x50\x00\x00\x00\x18\x00\x00\x00\x01\x00\x04\x80\x14\x00\x00\x00\x24\x00"
      "\x00\x00\x00\x00\x00\x00\x34\x00\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05"
      "\x20\x00\x00\x00\x20\x02\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00"
      "\x00\x00\x20\x02\x00\x00\x02\x00\x1c\x00\x01\x00\x00\x00\x00\x03\x14\x00"
      "\xff\x01\x1f\x00\x01\x01\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x80\x00"
      "\x00\x00\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x64\x00\x00\x00"
      "\x18\x00\x00\x00\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61"
      "\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61"
      "\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61"
      "\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61"
      "\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61"
      "\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x00\x00\x00\x00"
      "\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x05\x00",
      544);
  *(uint64_t*)0x20000e68 = 0x220;
  *(uint64_t*)0x20000e70 = 0x153e0;
  *(uint64_t*)0x20000e78 = 0x2001a800;
  memcpy((void*)0x2001a800,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00",
         32);
  *(uint64_t*)0x20000e80 = 0x20;
  *(uint64_t*)0x20000e88 = 0x157e0;
  *(uint64_t*)0x20000e90 = 0x2001a900;
  memcpy(
      (void*)0x2001a900,
      "\x01\x00\x04\x80\x14\x10\x00\x00\x20\x10\x00\x00\x00\x00\x00\x00\x14\x00"
      "\x00\x00\x02\x00\x00\x10\x08\x00\x00\x00\x00\x00\x18\x00\xff\x01\x1f\x00"
      "\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x0b"
      "\x18\x00\x00\x00\x00\x10\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00"
      "\x20\x02\x00\x00\x00\x00\x14\x00\xff\x01\x1f\x00\x01\x01\x00\x00\x00\x00"
      "\x00\x05\x12\x00\x00\x00\x00\x0b\x14\x00\x00\x00\x00\x10\x01\x01\x00\x00"
      "\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00\x14\x00\xbf\x01\x13\x00\x01\x01"
      "\x00\x00\x00\x00\x00\x05\x0b\x00\x00\x00\x00\x0b\x14\x00\x00\x00\x01\xe0"
      "\x01\x01\x00\x00\x00\x00\x00\x05\x0b\x00\x00\x00\x00\x00\x18\x00\xa9\x00"
      "\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x21\x02\x00\x00"
      "\x00\x0b\x18\x00\x00\x00\x00\xa0\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00"
      "\x00\x00\x21\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00",
      224);
  *(uint64_t*)0x20000e98 = 0xe0;
  *(uint64_t*)0x20000ea0 = 0x43000;
  *(uint64_t*)0x20000ea8 = 0x2001aa00;
  memcpy((void*)0x2001aa00,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x01"
         "\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20000eb0 = 0x40;
  *(uint64_t*)0x20000eb8 = 0x44000;
  *(uint64_t*)0x20000ec0 = 0x2001ab00;
  memcpy(
      (void*)0x2001ab00,
      "\x49\x4e\x44\x58\x28\x00\x09\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x28\x00\x00\x00\xb8\x06\x00\x00\xe8\x0f\x00\x00"
      "\x00\x00\x00\x00\x18\x00\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x04\x00"
      "\x68\x00\x52\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00"
      "\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x10\x00\x00\x00\x00"
      "\x00\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00"
      "\x08\x03\x24\x00\x41\x00\x74\x00\x74\x00\x72\x00\x44\x00\x65\x00\x66\x00"
      "\x00\x00\x00\x00\x01\x00\x08\x00\x00\x00\x00\x00\x08\x00\x68\x00\x52\x00"
      "\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x08\x03\x24\x00"
      "\x42\x00\x61\x00\x64\x00\x43\x00\x6c\x00\x75\x00\x73\x00\x00\x00\x00\x00"
      "\x07\x00\x06\x00\x00\x00\x00\x00\x06\x00\x60\x00\x50\x00\x00\x00\x00\x00"
      "\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00"
      "\xc8\x8d\xd6\x01\x00\x10\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00"
      "\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x03\x24\x00\x42\x00\x69\x00"
      "\x74\x00\x6d\x00\x61\x00\x70\x00\x07\x00\x00\x00\x00\x00\x07\x00\x60\x00"
      "\x4c\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00"
      "\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x20\x00\x00\x00\x00\x00\x00"
      "\x00\x20\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x05\x03"
      "\x24\x00\x42\x00\x6f\x00\x6f\x00\x74\x00\x69\x00\x6c\x00\x0b\x00\x00\x00"
      "\x00\x00\x0b\x00\x60\x00\x50\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00"
      "\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\x18\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x10"
      "\x00\x00\x00\x00\x07\x03\x24\x00\x45\x00\x78\x00\x74\x00\x65\x00\x6e\x00"
      "\x64\x00\x02\x00\x00\x00\x00\x00\x02\x00\x68\x00\x52\x00\x00\x00\x00\x00"
      "\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00"
      "\xc8\x8d\xd6\x01\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00"
      "\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x08\x03\x24\x00\x4c\x00\x6f\x00"
      "\x67\x00\x46\x00\x69\x00\x6c\x00\x65\x00\x00\x00\x00\x00\x01\x00\x00\x00"
      "\x00\x00\x00\x00\x01\x00\x60\x00\x4a\x00\x00\x00\x00\x00\x05\x00\x00\x00"
      "\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x00\x70\x00\x00\x00\x00\x00\x00\x00\x6c\x00\x00\x00\x00\x00\x00\x06\x00"
      "\x00\x00\x00\x00\x00\x00\x04\x03\x24\x00\x4d\x00\x46\x00\x54\x00\x00\x00"
      "\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x01\x00\x68\x00\x52\x00\x00\x00"
      "\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x00\x10\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00"
      "\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x08\x03\x24\x00\x4d\x00"
      "\x46\x00\x54\x00\x4d\x00\x69\x00\x72\x00\x72\x00\x00\x00\x02\x00\x00\x00"
      "\x09\x00\x00\x00\x00\x00\x09\x00\x60\x00\x50\x00\x00\x00\x00\x00\x05\x00"
      "\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00"
      "\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x06\x00\x00\x20\x00\x00\x00\x00\x07\x03\x24\x00\x53\x00\x65\x00\x63\x00"
      "\x75\x00\x72\x00\x65\x00\x0a\x00\x00\x00\x00\x00\x0a\x00\x60\x00\x50\x00"
      "\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x02\x00\x00\x00\x18\x00\x00\x00"
      "\x02\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x03\x24\x00"
      "\x55\x00\x70\x00\x43\x00\x61\x00\x73\x00\x65\x00\x03\x00\x00\x00\x00\x00"
      "\x03\x00\x60\x00\x50\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x80\x05"
      "\x2e\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00"
      "\x00\x00\x07\x03\x24\x00\x56\x00\x6f\x00\x6c\x00\x75\x00\x6d\x00\x65\x00"
      "\x05\x00\x00\x00\x00\x00\x05\x00\x58\x00\x44\x00\x00\x00\x00\x00\x05\x00"
      "\x00\x00\x00\x00\x05\x00\x80\x05\x2e\x00\xc8\x8d\xd6\x01\x90\x77\x79\x00"
      "\xc8\x8d\xd6\x01\x90\x77\x79\x00\xc8\x8d\xd6\x01\x80\x05\x2e\x00\xc8\x8d"
      "\xd6\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
      "\x26\x20\x00\x10\x00\x00\x00\x00\x01\x03\x2e\x00\x00\x00\x00\x00\x45\x00"
      "\x00\x00\x00\x00\x01\x00\x68\x00\x54\x00\x00\x00\x00\x00\x05\x00\x00\x00"
      "\x00\x00\x05\x00\x1b\x77\x79\x00\xc8\x8d\xd6\x01\x0b\x7b\x79\x00\xc8\x8d"
      "\xd6\x01\x0b\x7b\x79\x00\xc8\x8d\xd6\x01\x1b\x77\x79\x00\xc8\x8d\xd6\x01"
      "\x68\x00\x00\x00\x00\x00\x00\x00\x64\x00\x00\x00\x00\x00\x00\x00\x20\x00"
      "\x00\x00\x00\x00\x00\x00\x09\x00\x66\x00\x69\x00\x6c\x00\x65\x00\x2e\x00"
      "\x63\x00\x6f\x00\x6c\x00\x64\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00"
      "\x01\x00\x60\x00\x4c\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\x6a\x0a\x79\x00\xc8\x8d\xd6\x01\x12\x33\x79\x00\xc8\x8d\xd6\x01\x12\x33"
      "\x79\x00\xc8\x8d\xd6\x01\x6a\x0a\x79\x00\xc8\x8d\xd6\x01\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x20\x00\x00\x10\x00\x00"
      "\x00\x00\x05\x00\x66\x00\x69\x00\x6c\x00\x65\x00\x30\x00\x00\x00\x00\x00"
      "\x43\x00\x00\x00\x00\x00\x01\x00\x60\x00\x4c\x00\x00\x00\x00\x00\x05\x00"
      "\x00\x00\x00\x00\x05\x00\xce\x36\x79\x00\xc8\x8d\xd6\x01\x7f\x3e\x79\x00"
      "\xc8\x8d\xd6\x01\xec\x46\x79\x00\xc8\x8d\xd6\x01\xce\x36\x79\x00\xc8\x8d"
      "\xd6\x01\x10\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x00"
      "\x20\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00\x69\x00\x6c\x00\x65\x00"
      "\x31\x00\x00\x00\x18\x00\x44\x00\x00\x00\x00\x00\x01\x00\x60\x00\x4c\x00"
      "\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00\xbb\x4d\x79\x00\xc8\x8d"
      "\xd6\x01\xf6\x67\x79\x00\xc8\x8d\xd6\x01\x86\x6f\x79\x00\xc8\x8d\xd6\x01"
      "\xbb\x4d\x79\x00\xc8\x8d\xd6\x01\x00\x30\x00\x00\x00\x00\x00\x00\x28\x23"
      "\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x00"
      "\x69\x00\x6c\x00\x65\x00\x32\x00\x00\x00\x00\x00\x44\x00\x00\x00\x00\x00"
      "\x01\x00\x60\x00\x4c\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x05\x00"
      "\xbb\x4d\x79\x00\xc8\x8d\xd6\x01\xf6\x67\x79\x00\xc8\x8d\xd6\x01\x86\x6f"
      "\x79\x00\xc8\x8d\xd6\x01\xbb\x4d\x79\x00\xc8\x8d\xd6\x01\x00\x30\x00\x00"
      "\x00\x00\x00\x00\x28\x23\x00\x00\x00\x00\x00\x00\x20\x00\x00\x00\x00\x00"
      "\x00\x00\x05\x00\x66\x00\x69\x00\x6c\x00\x65\x00\x33\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x02\x00\x00\x00\x00\x00"
      "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
      1760);
  *(uint64_t*)0x20000ec8 = 0x6e0;
  *(uint64_t*)0x20000ed0 = 0x45000;
  *(uint64_t*)0x20000ed8 = 0x2001b200;
  memcpy((void*)0x2001b200,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x18\x00",
         32);
  *(uint64_t*)0x20000ee0 = 0x20;
  *(uint64_t*)0x20000ee8 = 0x457e0;
  *(uint64_t*)0x20000ef0 = 0x2001b300;
  memcpy((void*)0x2001b300,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x18\x00",
         32);
  *(uint64_t*)0x20000ef8 = 0x20;
  *(uint64_t*)0x20000f00 = 0x459e0;
  *(uint64_t*)0x20000f08 = 0x2001b400;
  memcpy((void*)0x2001b400,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x18\x00",
         32);
  *(uint64_t*)0x20000f10 = 0x20;
  *(uint64_t*)0x20000f18 = 0x45be0;
  *(uint64_t*)0x20000f20 = 0x2001b500;
  memcpy((void*)0x2001b500,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x18\x00",
         32);
  *(uint64_t*)0x20000f28 = 0x20;
  *(uint64_t*)0x20000f30 = 0x45de0;
  *(uint64_t*)0x20000f38 = 0x2001b600;
  memcpy((void*)0x2001b600,
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x18\x00\x24\x00"
         "\x53\x00\x54\x00\x41\x00\x4e\x00\x44\x00\x41\x00\x52\x00\x44\x00\x5f"
         "\x00\x49\x00\x4e\x00\x46\x00\x4f\x00\x52\x00\x4d\x00\x41\x00\x54\x00"
         "\x49\x00\x4f\x00\x4e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000f40 = 0x60;
  *(uint64_t*)0x20000f48 = 0x45fe0;
  *(uint64_t*)0x20000f50 = 0x2001b700;
  memcpy((void*)0x2001b700,
         "\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x30"
         "\x00\x00\x00\x00\x00\x00\x00\x48\x00\x00\x00\x00\x00\x00\x00\x24\x00"
         "\x41\x00\x54\x00\x54\x00\x52\x00\x49\x00\x42\x00\x55\x00\x54\x00\x45"
         "\x00\x5f\x00\x4c\x00\x49\x00\x53\x00\x54\x00\x00\x00",
         64);
  *(uint64_t*)0x20000f58 = 0x40;
  *(uint64_t*)0x20000f60 = 0x46080;
  *(uint64_t*)0x20000f68 = 0x2001b800;
  memcpy((void*)0x2001b800,
         "\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\x24\x00"
         "\x46\x00\x49\x00\x4c\x00\x45\x00\x5f\x00\x4e\x00\x41\x00\x4d\x00\x45"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20000f70 = 0x40;
  *(uint64_t*)0x20000f78 = 0x46120;
  *(uint64_t*)0x20000f80 = 0x2001b900;
  memcpy((void*)0x2001b900,
         "\x30\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x42\x00\x00\x00\x44"
         "\x00\x00\x00\x00\x00\x00\x00\x42\x02\x00\x00\x00\x00\x00\x00\x24\x00"
         "\x4f\x00\x42\x00\x4a\x00\x45\x00\x43\x00\x54\x00\x5f\x00\x49\x00\x44"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20000f88 = 0x40;
  *(uint64_t*)0x20000f90 = 0x461c0;
  *(uint64_t*)0x20000f98 = 0x2001ba00;
  memcpy((void*)0x2001ba00,
         "\x40\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x24\x00"
         "\x53\x00\x45\x00\x43\x00\x55\x00\x52\x00\x49\x00\x54\x00\x59\x00\x5f"
         "\x00\x44\x00\x45\x00\x53\x00\x43\x00\x52\x00\x49\x00\x50\x00\x54\x00"
         "\x4f\x00\x52\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000fa0 = 0x60;
  *(uint64_t*)0x20000fa8 = 0x46260;
  *(uint64_t*)0x20000fb0 = 0x2001bb00;
  memcpy((void*)0x2001bb00,
         "\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\x24\x00"
         "\x56\x00\x4f\x00\x4c\x00\x55\x00\x4d\x00\x45\x00\x5f\x00\x4e\x00\x41"
         "\x00\x4d\x00\x45\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20000fb8 = 0x40;
  *(uint64_t*)0x20000fc0 = 0x46300;
  *(uint64_t*)0x20000fc8 = 0x2001bc00;
  memcpy((void*)0x2001bc00,
         "\x60\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x02"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x24\x00"
         "\x56\x00\x4f\x00\x4c\x00\x55\x00\x4d\x00\x45\x00\x5f\x00\x49\x00\x4e"
         "\x00\x46\x00\x4f\x00\x52\x00\x4d\x00\x41\x00\x54\x00\x49\x00\x4f\x00"
         "\x4e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20000fd0 = 0x60;
  *(uint64_t*)0x20000fd8 = 0x463a0;
  *(uint64_t*)0x20000fe0 = 0x2001bd00;
  memcpy(
      (void*)0x2001bd00,
      "p\000\000\000\000\000\000\000\000\000\000\000@"
      "\000\000\000\f\000\000\000\000\000\000\000\f\000\000\000\000\000\000\000"
      "$\000D\000A\000T\000A\000\000\000\000\000\000\000\000\000\000\000\000"
      "\000\000\000\000\000\000\000\000\000\000\000",
      64);
  *(uint64_t*)0x20000fe8 = 0x40;
  *(uint64_t*)0x20000ff0 = 0x46440;
  *(uint64_t*)0x20000ff8 = 0x2001be00;
  memcpy((void*)0x2001be00,
         "\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\x24\x00"
         "\x49\x00\x4e\x00\x44\x00\x45\x00\x58\x00\x5f\x00\x52\x00\x4f\x00\x4f"
         "\x00\x54\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20001000 = 0x40;
  *(uint64_t*)0x20001008 = 0x464e0;
  *(uint64_t*)0x20001010 = 0x2001bf00;
  memcpy((void*)0x2001bf00,
         "\x90\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\x24\x00"
         "\x49\x00\x4e\x00\x44\x00\x45\x00\x58\x00\x5f\x00\x41\x00\x4c\x00\x4c"
         "\x00\x4f\x00\x43\x00\x41\x00\x54\x00\x49\x00\x4f\x00\x4e\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20001018 = 0x60;
  *(uint64_t*)0x20001020 = 0x46580;
  *(uint64_t*)0x20001028 = 0x2001c000;
  memcpy((void*)0x2001c000,
         "\xa0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\x24\x00"
         "\x42\x00\x49\x00\x54\x00\x4d\x00\x41\x00\x50\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20001030 = 0x40;
  *(uint64_t*)0x20001038 = 0x46620;
  *(uint64_t*)0x20001040 = 0x2001c100;
  memcpy((void*)0x2001c100,
         "\xb0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\x24\x00"
         "\x52\x00\x45\x00\x50\x00\x41\x00\x52\x00\x53\x00\x45\x00\x5f\x00\x50"
         "\x00\x4f\x00\x49\x00\x4e\x00\x54\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20001048 = 0x40;
  *(uint64_t*)0x20001050 = 0x466c0;
  *(uint64_t*)0x20001058 = 0x2001c200;
  memcpy((void*)0x2001c200,
         "\xc0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x24\x00"
         "\x45\x00\x41\x00\x5f\x00\x49\x00\x4e\x00\x46\x00\x4f\x00\x52\x00\x4d"
         "\x00\x41\x00\x54\x00\x49\x00\x4f\x00\x4e\x00\x00\x00",
         64);
  *(uint64_t*)0x20001060 = 0x40;
  *(uint64_t*)0x20001068 = 0x46760;
  *(uint64_t*)0x20001070 = 0x2001c300;
  memcpy((void*)0x2001c300,
         "\xd0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x08"
         "\x00\x00\x00\x00\x00\x00\x00\x08\x00\x00\x00\x00\x00\x00\x00\x24\x00"
         "\x45\x00\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         64);
  *(uint64_t*)0x20001078 = 0x40;
  *(uint64_t*)0x20001080 = 0x46800;
  *(uint64_t*)0x20001088 = 0x2001c400;
  memcpy((void*)0x2001c400,
         "\xe0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x24\x00"
         "\x4c\x00\x4f\x00\x47\x00\x47\x00\x45\x00\x44\x00\x5f\x00\x55\x00\x54"
         "\x00\x49\x00\x4c\x00\x49\x00\x54\x00\x59\x00\x5f\x00\x53\x00\x54\x00"
         "\x52\x00\x45\x00\x41\x00\x4d\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00",
         96);
  *(uint64_t*)0x20001090 = 0x60;
  *(uint64_t*)0x20001098 = 0x468a0;
  *(uint64_t*)0x200010a0 = 0x2001c500;
  memcpy((void*)0x2001c500,
         "\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00",
         32);
  *(uint64_t*)0x200010a8 = 0x20;
  *(uint64_t*)0x200010b0 = 0x46940;
  *(uint64_t*)0x200010b8 = 0x2001c600;
  memcpy((void*)0x2001c600,
         "\xf7\xff\x7f\x00\x00\x00\x00\x00\xf8\xff\xff\xff\xff\xff\xff\xff\xff"
         "\xff\xff\xff\xff\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\xff\xff"
         "\xff\xff\xff\xff\xff\xff\x0f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
         "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80",
         64);
  *(uint64_t*)0x200010c0 = 0x40;
  *(uint64_t*)0x200010c8 = 0x47000;
  *(uint64_t*)0x200010d0 = 0x2001c700;
  memcpy(
      (void*)0x2001c700,
      "\xf0\x12\x03\xf8\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x7c\x00"
      "\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x58\x00\x00\x00\x00\x00\x00\x00"
      "\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00\x89\x00"
      "\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00\x18\x00"
      "\x89\x00\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02"
      "\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00"
      "\x00\x00\x51\x24\xb3\x00\x01\x01\x00\x00\x80\x00\x00\x00\x00\x00\x00\x00"
      "\x7c\x00\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x58\x00\x00\x00\x00\x00"
      "\x00\x00\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00"
      "\x9f\x01\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00"
      "\x18\x00\x9f\x01\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00"
      "\x20\x02\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02"
      "\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00"
      "\x00\x00\x00\x00",
      256);
  *(uint64_t*)0x200010d8 = 0x100;
  *(uint64_t*)0x200010e0 = 0x48000;
  *(uint8_t*)0x2007dc00 = 0;
  syz_mount_image(0x20000000, 0x20000100, 0, 0x9f, 0x20000200, 0, 0x2007dc00);
  return 0;
}
